@@ -123,6 +123,8 @@ void slurm_sprint_cpu_bind_type(char *str, cpu_bind_type_t cpu_bind_type)
 		strcat(str, "sockets,");
 	if (cpu_bind_type & CPU_BIND_TO_LDOMS)
 		strcat(str, "ldoms,");
+	if (cpu_bind_type & CPU_BIND_TO_BOARDS)
+		strcat(str, "boards,");
 	if (cpu_bind_type & CPU_BIND_NONE)
 		strcat(str, "none,");
 	if (cpu_bind_type & CPU_BIND_RANK)
@@ -137,6 +139,8 @@ void slurm_sprint_cpu_bind_type(char *str, cpu_bind_type_t cpu_bind_type)
 		strcat(str, "map_ldom,");
 	if (cpu_bind_type & CPU_BIND_LDMASK)
 		strcat(str, "mask_ldom,");
+	if (cpu_bind_type & CPU_BIND_CPUSETS)
+		strcat(str, "cpusets,");
 
 	if (*str) {
 		str[strlen(str)-1] = '\0';	/* remove trailing ',' */
