@@ -89,6 +89,7 @@ static bool slurm_started = false;
 static log_options_t log_opts = LOG_OPTS_STDERR_ONLY;
 static host_usage_t *host_usage = NULL;
 static hostlist_t total_hl = NULL;
+static int err_msg_len = 400;
 
 int sig_array[] = {
 	SIGINT,  SIGQUIT, SIGCONT, SIGTERM, SIGHUP,
@@ -168,6 +169,9 @@ static int _unpack_srun_ctx(slurm_step_ctx_t **step_ctx, Buf buffer)
 	if (rc != SLURM_SUCCESS)
 		goto unpack_error;
 
+	ctx->job_id	= ctx->step_req->job_id;
+	ctx->user_id	= ctx->step_req->user_id;
+
 	safe_unpack32(&tmp_32, buffer);
 	ctx->launch_state = step_launch_state_create(ctx);
 	ctx->launch_state->slurmctld_socket_fd = tmp_32;
@@ -238,6 +242,8 @@ static srun_job_t * _unpack_srun_job_rec(Buf buffer)
 		host_ptr++;
 	}
 
+	slurm_step_ctx_params_t_init(&job_data->ctx_params);
+
 	return job_data;
 
 unpack_error:
@@ -467,8 +473,8 @@ static char *_uint16_array_to_str(int array_len, const uint16_t *array)
 	for (i = 0; i < array_len; i++) {
 		if ((i+1 < array_len)
 		    && (array[i] == array[i+1])) {
-				previous++;
-				continue;
+			previous++;
+			continue;
 		}
 
 		if (i == array_len-1) /* last time through loop */
@@ -932,7 +938,9 @@ extern int pe_rm_connect(rmhandle_t resource_mgr,
 		debug("got pe_rm_connect called");
 		launch_common_set_stdio_fds(job, &cio_fds);
 	} else {
-		*error_msg = xstrdup_printf("pe_rm_connect: unknown caller");
+		*error_msg = malloc(sizeof(char) * err_msg_len);
+		snprintf(*error_msg, err_msg_len,
+			 "pe_rm_connect: unknown caller");
 		error("%s", *error_msg);
 		return -1;
 	}
@@ -945,9 +953,10 @@ extern int pe_rm_connect(rmhandle_t resource_mgr,
 		if (!name) {
 			if (hl)
 				hostlist_destroy(hl);
-			*error_msg = xstrdup_printf(
-				"pe_rm_connect: unknown host for ip %s",
-				connect_param->machine_name[i]);
+			*error_msg = malloc(sizeof(char) * err_msg_len);
+			snprintf(*error_msg, err_msg_len,
+				 "pe_rm_connect: unknown host for ip %s",
+				 connect_param->machine_name[i]);
 			error("%s", *error_msg);
 			return -1;
 		}
@@ -964,20 +973,24 @@ extern int pe_rm_connect(rmhandle_t resource_mgr,
 	}
 
 	if (!hl) {
-		*error_msg = xstrdup_printf(
-			"pe_rm_connect: machine_count 0? it came in as "
-			"%d but we didn't get a hostlist",
-			connect_param->machine_count);
+		*error_msg = malloc(sizeof(char) * err_msg_len);
+		snprintf(*error_msg, err_msg_len,
+			 "pe_rm_connect: machine_count 0? it came in as "
+			 "%d but we didn't get a hostlist",
+			 connect_param->machine_count);
 		error("%s", *error_msg);
 		return -1;
 	}
 
-	hostlist_sort(hl);
+	/* Can't sort the list here because the ordering matters when
+	 * launching tasks.
+	 */
+	//hostlist_sort(hl);
 	xfree(job->nodelist);
 	job->nodelist = hostlist_ranged_string_xmalloc(hl);
 	hostlist_destroy(hl);
 
-	hostlist_sort(total_hl);
+	//hostlist_sort(total_hl);
 	total_node_list = hostlist_ranged_string_xmalloc(total_hl);
 	node_cnt = hostlist_count(total_hl);
 
@@ -993,9 +1006,10 @@ extern int pe_rm_connect(rmhandle_t resource_mgr,
 						node_cnt, &task_num)
 	    != SLURM_SUCCESS) {
 		xfree(total_node_list);
-		*error_msg = xstrdup_printf(
-			"pe_rm_connect: problem with hack: %s",
-			slurm_strerror(errno));
+		*error_msg = malloc(sizeof(char) * err_msg_len);
+		snprintf(*error_msg, err_msg_len,
+			 "pe_rm_connect: problem with hack: %s",
+			 slurm_strerror(errno));
 		error("%s", *error_msg);
 		return -1;
 	}
@@ -1008,9 +1022,10 @@ extern int pe_rm_connect(rmhandle_t resource_mgr,
 	step_callbacks.step_timeout  = _self_timeout;
 
 	if (launch_g_step_launch(job, &cio_fds, &global_rc, &step_callbacks)) {
-		*error_msg = xstrdup_printf(
-			"pe_rm_connect: problem with launch: %s",
-			slurm_strerror(errno));
+		*error_msg = malloc(sizeof(char) * err_msg_len);
+		snprintf(*error_msg, err_msg_len,
+			 "pe_rm_connect: problem with launch: %s",
+			 slurm_strerror(errno));
 		error("%s", *error_msg);
 		return -1;
 	}
@@ -1019,16 +1034,19 @@ extern int pe_rm_connect(rmhandle_t resource_mgr,
 				SLURM_STEP_CTX_USER_MANAGED_SOCKETS,
 				&fd_cnt, &ctx_sockfds);
 	if (ctx_sockfds == NULL) {
-		*error_msg = xstrdup_printf(
-			"pe_rm_connect: Unable to get pmd IO socket array %d",
-			rc);
+		*error_msg = malloc(sizeof(char) * err_msg_len);
+		snprintf(*error_msg, err_msg_len,
+			 "pe_rm_connect: Unable to get pmd IO socket array %d",
+			 rc);
 		error("%s", *error_msg);
 		return -1;
 	}
 	if (fd_cnt != task_num) {
-		*error_msg = xstrdup_printf(
-			"pe_rm_connect: looking for %d sockets but got back %d",
-			connect_param->machine_count, fd_cnt);
+		*error_msg = malloc(sizeof(char) * err_msg_len);
+		snprintf(*error_msg, err_msg_len,
+			 "pe_rm_connect: looking for %d sockets but "
+			 "got back %d",
+			 connect_param->machine_count, fd_cnt);
 		error("%s", *error_msg);
 		return -1;
 	}
@@ -1097,7 +1115,7 @@ extern int pe_rm_free_event(rmhandle_t resource_mgr, job_event_t ** job_event)
 
 	debug("got pe_rm_free_event called");
 	if (job_event) {
-		xfree(*job_event);
+		free(*job_event);
 	}
 	return 0;
 }
@@ -1169,7 +1187,9 @@ extern int pe_rm_get_event(rmhandle_t resource_mgr, job_event_t **job_event,
 		debug("pe_rm_get_event called");
 		return 0;
 	} else if (pm_type != PM_POE) {
-		*error_msg = xstrdup_printf("pe_rm_get_event: unknown caller");
+		*error_msg = malloc(sizeof(char) * err_msg_len);
+		snprintf(*error_msg, err_msg_len,
+			 "pe_rm_get_event: unknown caller");
 		error("%s", *error_msg);
 		return -1;
 	}
@@ -1177,10 +1197,11 @@ extern int pe_rm_get_event(rmhandle_t resource_mgr, job_event_t **job_event,
 	debug("got pe_rm_get_event called %d %p %p",
 	      rm_timeout, job_event, *job_event);
 
-	ret_event = xmalloc(sizeof(job_event_t));
+	ret_event = malloc(sizeof(job_event_t));
+	memset(ret_event, 0, sizeof(job_event_t));
 	*job_event = ret_event;
 	ret_event->event = JOB_STATE_EVENT;
-	state = xmalloc(sizeof(int));
+	state = malloc(sizeof(int));
 	*state = JOB_STATE_RUNNING;
 	ret_event->event_data = (void *)state;
 
@@ -1219,7 +1240,7 @@ extern int pe_rm_get_event(rmhandle_t resource_mgr, job_event_t **job_event,
 extern int pe_rm_get_job_info(rmhandle_t resource_mgr, job_info_t **job_info,
 			      char ** error_msg)
 {
-	job_info_t *ret_info = xmalloc(sizeof(job_info_t));
+	job_info_t *ret_info = malloc(sizeof(job_info_t));
 	int i, j;
 	slurm_step_layout_t *step_layout;
 	hostlist_t hl;
@@ -1230,16 +1251,19 @@ extern int pe_rm_get_job_info(rmhandle_t resource_mgr, job_info_t **job_info,
 	nrt_tableinfo_t *tables, *table_ptr;
 	nrt_job_key_t job_key;
 	job_step_create_response_msg_t *resp;
-	int network_id_cnt = 0;
+	int network_id_cnt = 0, size = 0;
 	nrt_network_id_t *network_id_list;
 	char value[32];
 
+	memset(ret_info, 0, sizeof(job_info_t));
+
 	if (pm_type == PM_PMD) {
 		debug("pe_rm_get_job_info called");
 		return 0;
 	} else if (pm_type != PM_POE) {
-		*error_msg = xstrdup_printf(
-			"pe_rm_get_job_info: unknown caller");
+		*error_msg = malloc(sizeof(char) * err_msg_len);
+		snprintf(*error_msg, err_msg_len,
+			 "pe_rm_get_job_info: unknown caller");
 		error("%s", *error_msg);
 		return -1;
 	}
@@ -1256,7 +1280,8 @@ extern int pe_rm_get_job_info(rmhandle_t resource_mgr, job_info_t **job_info,
 	}
 
 	*job_info = ret_info;
-	ret_info->job_name = xstrdup(opt.job_name);
+	if (opt.job_name)
+		ret_info->job_name = strdup(opt.job_name);
 	ret_info->rm_id = NULL;
 	ret_info->procs = job->ntasks;
 	ret_info->max_instances = 0;
@@ -1266,8 +1291,9 @@ extern int pe_rm_get_job_info(rmhandle_t resource_mgr, job_info_t **job_info,
 
 	slurm_step_ctx_get(job->step_ctx, SLURM_STEP_CTX_RESP, &resp);
 	if (!resp) {
-		*error_msg = xstrdup_printf(
-			"pe_rm_get_job_info: no step response in step ctx");
+		*error_msg = malloc(sizeof(char) * err_msg_len);
+		snprintf(*error_msg, err_msg_len,
+			 "pe_rm_get_job_info: no step response in step ctx");
 		error("%s", *error_msg);
 		return -1;
 	}
@@ -1295,10 +1321,16 @@ extern int pe_rm_get_job_info(rmhandle_t resource_mgr, job_info_t **job_info,
 
 	slurm_jobinfo_ctx_get(
 		resp->switch_job, NRT_JOBINFO_TABLESPERTASK, &table_cnt);
-	ret_info->protocol = xmalloc(sizeof(char *)*(table_cnt+1));
-	ret_info->mode = xmalloc(sizeof(char *)*(table_cnt+1));
-	ret_info->devicename = xmalloc(sizeof(char *)*(table_cnt+1));
-	ret_info->instance = xmalloc(sizeof(int)*(table_cnt+2));
+	size = sizeof(char *)*(table_cnt+1);
+	ret_info->protocol = malloc(size);
+	memset(ret_info->protocol, 0, size);
+	ret_info->mode = malloc(size);
+	memset(ret_info->mode, 0, size);
+	ret_info->devicename = malloc(size);
+	memset(ret_info->devicename, 0, size);
+	size = sizeof(char *)*(table_cnt+2);
+	ret_info->instance = malloc(size);
+	memset(ret_info->instance, 0, size);
 
 	slurm_jobinfo_ctx_get(resp->switch_job, NRT_JOBINFO_TABLEINFO, &tables);
 	debug2("got count of %d", table_cnt);
@@ -1314,9 +1346,14 @@ extern int pe_rm_get_job_info(rmhandle_t resource_mgr, job_info_t **job_info,
 				table_ptr->network_id;
 		}
 /* FIXME: Format of these data structure contents not well defined */
-		ret_info->protocol[i] = xstrdup(table_ptr->protocol_name);
-		ret_info->mode[i] = xstrdup(mode);
-		ret_info->devicename[i] = xstrdup(table_ptr->adapter_name);
+		if (table_ptr->protocol_name)
+			ret_info->protocol[i] =
+				strdup(table_ptr->protocol_name);
+		if (mode)
+			ret_info->mode[i] = strdup(mode);
+		if (table_ptr->adapter_name)
+			ret_info->devicename[i] =
+				strdup(table_ptr->adapter_name);
 		ret_info->instance[i] = table_ptr->instance;
 		ret_info->max_instances = MAX(ret_info->max_instances,
 					      ret_info->instance[i]);
@@ -1331,8 +1368,10 @@ extern int pe_rm_get_job_info(rmhandle_t resource_mgr, job_info_t **job_info,
 
 	step_layout = launch_common_get_slurm_step_layout(job);
 
-	ret_info->hosts = xmalloc(sizeof(host_usage_t)
-				  * (ret_info->host_count+1));
+	size = sizeof(host_usage_t) * (ret_info->host_count+1);
+	ret_info->hosts = malloc(size);
+	memset(ret_info->hosts, 0, size);
+
 	host_ptr = ret_info->hosts;
 	i=0;
 	hl = hostlist_create(step_layout->node_list);
@@ -1340,10 +1379,12 @@ extern int pe_rm_get_job_info(rmhandle_t resource_mgr, job_info_t **job_info,
 		slurm_addr_t addr;
 		host_ptr->host_name = host;
 		slurm_conf_get_addr(host, &addr);
-		host_ptr->host_address = xstrdup(inet_ntoa(addr.sin_addr));
+		host_ptr->host_address = strdup(inet_ntoa(addr.sin_addr));
 		host_ptr->task_count = step_layout->tasks[i];
-		host_ptr->task_ids =
-			xmalloc(sizeof(int) * host_ptr->task_count);
+		size = sizeof(int) * host_ptr->task_count;
+		host_ptr->task_ids = malloc(size);
+		memset(host_ptr->task_ids, 0, size);
+
 		/* Task ids are already set up in the layout, so just
 		   use them.
 		*/
@@ -1653,7 +1694,7 @@ extern int pe_rm_init(int *rmapi_version, rmhandle_t *resource_mgr, char *rm_id,
 				xstrcat(opt.network, "bulk_xfer");
 			}
 			xfree(bulk_xfer);
-				xfree(collectives);
+			xfree(collectives);
 			xfree(euidevice);
 			xfree(euilib);
 			xfree(immediate);
@@ -1690,17 +1731,19 @@ extern int pe_rm_init(int *rmapi_version, rmhandle_t *resource_mgr, char *rm_id,
 		if ((srun_debug = getenv("SLURM_STEP_ID")))
 			step_id = atoi(srun_debug);
 		if (job_id == -1 || step_id == -1) {
-			*error_msg = xstrdup_printf(
-				"pe_rm_init: SLURM_JOB_ID or SLURM_STEP_ID "
-				"not found %d.%d", job_id, step_id);
+			*error_msg = malloc(sizeof(char) * err_msg_len);
+			snprintf(*error_msg, err_msg_len,
+				 "pe_rm_init: SLURM_JOB_ID or SLURM_STEP_ID "
+				 "not found %d.%d", job_id, step_id);
 			error("%s", *error_msg);
 			return -1;
 		}
 
 		job = _read_job_srun_agent();
 		if (!job) {
-			*error_msg = xstrdup_printf(
-				"pe_rm_init: no job created");
+			*error_msg = malloc(sizeof(char) * err_msg_len);
+			snprintf(*error_msg, err_msg_len,
+				 "pe_rm_init: no job created");
 			error("%s", *error_msg);
 			return -1;
 		}
@@ -1715,7 +1758,9 @@ extern int pe_rm_init(int *rmapi_version, rmhandle_t *resource_mgr, char *rm_id,
 		 * PMD to fanout child processes on other nodes */
 		_spawn_fe_agent();
 	} else {
-		*error_msg = xstrdup_printf("pe_rm_init: unknown caller");
+		*error_msg = malloc(sizeof(char) * err_msg_len);
+		snprintf(*error_msg, err_msg_len,
+			 "pe_rm_init: unknown caller");
 		error("%s", *error_msg);
 		return -1;
 	}
@@ -1749,7 +1794,7 @@ extern int pe_rm_send_event(rmhandle_t resource_mgr, job_event_t *job_event,
 
 	if ((job_event->event == JOB_CKPT_COMPLETE) && job) {
 		struct ckpt_end_data *ckpt_end_ptr = (struct ckpt_end_data *)
-						     job_event->event_data;
+			job_event->event_data;
 		rc = slurm_checkpoint_complete(job->jobid, job->stepid,
 					       ckpt_end_ptr->ckpt_start_time,
 					       ckpt_end_ptr->ckpt_rc,
@@ -1800,7 +1845,9 @@ int pe_rm_submit_job(rmhandle_t resource_mgr, job_command_t job_cmd,
 		if (slurm_cmd_fname)
 			poe_cmd_fname = getenv("MP_CMDFILE");
 	} else {
-		*error_msg = xstrdup_printf("pe_rm_submit_job: unknown caller");
+		*error_msg = malloc(sizeof(char) * err_msg_len);
+		snprintf(*error_msg, err_msg_len,
+			 "pe_rm_submit_job: unknown caller");
 		error("%s", *error_msg);
 		return -1;
 	}
@@ -1808,9 +1855,10 @@ int pe_rm_submit_job(rmhandle_t resource_mgr, job_command_t job_cmd,
 	debug("got pe_rm_submit_job called %d", job_cmd.job_format);
 	if (job_cmd.job_format != 1) {
 		/* We don't handle files */
-		*error_msg = xstrdup_printf(
-			"pe_rm_submit_job: SLURM doesn't handle files "
-			"to submit_job");
+		*error_msg = malloc(sizeof(char) * err_msg_len);
+		snprintf(*error_msg, err_msg_len,
+			 "pe_rm_submit_job: SLURM doesn't handle files "
+			 "to submit_job");
 		error("%s", *error_msg);
 		return -1;
 	}
