@@ -248,6 +248,33 @@ mgr_launch_tasks_setup(launch_tasks_request_msg_t *msg, slurm_addr_t *cli,
 	return job;
 }
 
+inline static int
+_send_srun_resp_msg(slurm_msg_t *resp_msg, uint32_t nnodes)
+{
+	int rc, retry = 0, max_retry = 0;
+	unsigned long delay = 100000;
+
+	while (1) {
+		rc = slurm_send_only_node_msg(resp_msg);
+		if ((rc == SLURM_SUCCESS) || (errno != ETIMEDOUT))
+			break;
+
+		if (!max_retry)
+			max_retry = (nnodes / 1024) + 1;
+
+		if (retry > max_retry)
+			break;
+
+		debug3("_send_srun_resp_msg: failed to send msg type %u: %m",
+			resp_msg->msg_type);
+		usleep(delay);
+		if (delay < 800000)
+			delay *= 2;
+		retry ++;
+	}
+	return rc;
+}
+
 /*
  * Find the maximum task return code
  */
@@ -652,8 +679,9 @@ _send_exit_msg(slurmd_job_t *job, uint32_t *tid, int n, int status)
 		    (resp.address.sin_port == 0)   &&
 		    (resp.address.sin_addr.s_addr == 0))
 			continue;	/* no srun or sattach here */
-		if (slurm_send_only_node_msg(&resp) != SLURM_SUCCESS)
-			verbose("Failed to send MESSAGE_TASK_EXIT: %m");
+
+		if (_send_srun_resp_msg(&resp, job->nnodes) != SLURM_SUCCESS)
+			error("Failed to send MESSAGE_TASK_EXIT: %m");
 	}
 	list_iterator_destroy(i);
 
@@ -1986,28 +2014,6 @@ static int _drain_node(char *reason)
 	return SLURM_SUCCESS;
 }
 
-inline static int
-_send_launch_resp_msg(slurm_msg_t *resp_msg, uint32_t nnodes)
-{
-	int rc, retry = 0, max_retry;
-	unsigned long delay = 100000;
-
-	max_retry = (nnodes / 1024) + 1;
-	while (1) {
-		rc = slurm_send_only_node_msg(resp_msg);
-		if ((rc == SLURM_SUCCESS) ||
-		    (errno != ETIMEDOUT) ||
-		    (retry > max_retry))
-			break;
-		debug3("_send_launch_resp_msg: failed to send msg: %m");
-		usleep(delay);
-		if (delay < 800000)
-			delay *= 2;
-		retry ++;
-	}
-	return rc;
-}
-
 static void
 _send_launch_failure (launch_tasks_request_msg_t *msg, slurm_addr_t *cli, int rc)
 {
@@ -2037,7 +2043,7 @@ _send_launch_failure (launch_tasks_request_msg_t *msg, slurm_addr_t *cli, int rc
 	resp.return_code   = rc ? rc : -1;
 	resp.count_of_pids = 0;
 
-	if (_send_launch_resp_msg(&resp_msg, msg->nnodes) != SLURM_SUCCESS)
+	if (_send_srun_resp_msg(&resp_msg, msg->nnodes) != SLURM_SUCCESS)
 		error("Failed to send RESPONSE_LAUNCH_TASKS: %m");
 	xfree(name);
 	return;
@@ -2072,7 +2078,7 @@ _send_launch_resp(slurmd_job_t *job, int rc)
 		resp.task_ids[i] = job->task[i]->gtid;
 	}
 
-	if (_send_launch_resp_msg(&resp_msg, job->nnodes) != SLURM_SUCCESS)
+	if (_send_srun_resp_msg(&resp_msg, job->nnodes) != SLURM_SUCCESS)
 		error("failed to send RESPONSE_LAUNCH_TASKS: %m");
 
 	xfree(resp.local_pids);
